##  Summary
This tutorial has provided an introduction to creating custom reports using the LeanIX Reporting Framework. You learned how to:
  * Import the LeanIX Reporting Library, initialize the LeanIX Reporting Framework, and create a custom report class
  * Configure the report and render fact sheet data by creating a customized view of your fact sheets
  * Apply the lx.ready() method to indicate that the report is prepared and ready for receiving and processing data


YesNo
Send
Help us provide a better digital experience for you and all other visitors.
What is the purpose of your visit to our website today?
  * Understand software features and benefits for a possible purchase
  * Find information about how to use the software
  * Find implementation or configuration information
  * Find information on installing or upgrading the software
  * Find information to troubleshoot and resolve issues that I'm encountering
  * Find developer or API information
  * Learn about new or updated product features
  * Other (please specify)


You can write a maximum of 255 characters.
Were you able to complete your task?
  * Yes
  * No


Why were you not able to complete your task today?
You can write a maximum of 4000 characters.
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
